libgda r3140 - in trunk: . doc/C doc/C/tmpl libgda tools



Author: murrayc
Date: Thu Apr 10 05:06:05 2008
New Revision: 3140
URL: http://svn.gnome.org/viewvc/libgda?rev=3140&view=rev

Log:
2008-04-10  Murray Cumming  <murrayc murrayc com>

* doc/C/prov-writing.xml:
* doc/C/tmpl/gda-connection.sgml:
* libgda/gda-config.c (gda_config_get_provider_object,
  gda_config_list_providers, load_providers_from_dir):
* libgda/gda-connection.c (gda_connection_class_init,
  gda_connection_get_property, gda_connection_open_from_dsn,
  gda_connection_open, gda_connection_get_cnc_string,
  gda_connection_get_authentication):
* libgda/gda-connection.h (GdaConnectionMetaType):
* tools/gda-sql.c (extra_command_manage_cnc): Rename authentification to 
authentication in API and implementation.

Modified:
   trunk/ChangeLog
   trunk/doc/C/prov-writing.xml
   trunk/doc/C/tmpl/gda-connection.sgml
   trunk/libgda/gda-config.c
   trunk/libgda/gda-connection.c
   trunk/libgda/gda-connection.h
   trunk/tools/gda-sql.c

Modified: trunk/doc/C/prov-writing.xml
==============================================================================
--- trunk/doc/C/prov-writing.xml	(original)
+++ trunk/doc/C/prov-writing.xml	Thu Apr 10 05:06:05 2008
@@ -689,7 +689,7 @@
     <sect2>
       <title>plugin_get_auth_spec()</title>
       <para>
-	This function returns a description of the authentification information required by the provider. If the
+	This function returns a description of the authentication information required by the provider. If the
 	only information is a username/password pair, then it is not necessary to implement that function.
       </para>
       <para>

Modified: trunk/doc/C/tmpl/gda-connection.sgml
==============================================================================
--- trunk/doc/C/tmpl/gda-connection.sgml	(original)
+++ trunk/doc/C/tmpl/gda-connection.sgml	Thu Apr 10 05:06:05 2008
@@ -403,7 +403,7 @@
 @Returns: 
 
 
-<!-- ##### FUNCTION gda_connection_get_authentification ##### -->
+<!-- ##### FUNCTION gda_connection_get_authentication ##### -->
 <para>
 
 </para>

Modified: trunk/libgda/gda-config.c
==============================================================================
--- trunk/libgda/gda-config.c	(original)
+++ trunk/libgda/gda-config.c	Thu Apr 10 05:06:05 2008
@@ -1055,7 +1055,7 @@
  *  <listitem><para>Provider name</para></listitem>
  *  <listitem><para>Description</para></listitem>
  *  <listitem><para>DSN parameters</para></listitem>
- *  <listitem><para>Authentification parameters</para></listitem>
+ *  <listitem><para>Authentication parameters</para></listitem>
  *  <listitem><para>File</para></listitem>
  * </itemizedlist>
  *
@@ -1083,7 +1083,7 @@
 	gda_data_model_set_column_title (model, 0, _("Provider"));
 	gda_data_model_set_column_title (model, 1, _("Description"));
 	gda_data_model_set_column_title (model, 2, _("DSN parameters"));
-	gda_data_model_set_column_title (model, 3, _("Authentification"));
+	gda_data_model_set_column_title (model, 3, _("Authentication"));
 	gda_data_model_set_column_title (model, 4, _("File"));
 	g_object_set_data (G_OBJECT (model), "name", _("List of installed providers"));
 
@@ -1272,7 +1272,7 @@
 		else
 			g_warning ("Provider '%s' does not provide a DSN spec", info->id);
 
-		/* Authentification parameters */
+		/* Authentication parameters */
 		info->auth_params = NULL;
 		if (plugin_get_auth_spec) {
 			GError *error = NULL;

Modified: trunk/libgda/gda-connection.c
==============================================================================
--- trunk/libgda/gda-connection.h	(original)
+++ trunk/libgda/gda-connection.h	Thu Apr 10 05:06:05 2008
@@ -152,7 +152,7 @@
 const gchar         *gda_connection_get_dsn              (GdaConnection *cnc);
 gboolean             gda_connection_set_dsn              (GdaConnection *cnc, const gchar *datasource);
 const gchar         *gda_connection_get_cnc_string       (GdaConnection *cnc);
-const gchar         *gda_connection_get_authentification (GdaConnection *cnc);
+const gchar         *gda_connection_get_authentication (GdaConnection *cnc);
 
 void                 gda_connection_add_event            (GdaConnection *cnc, GdaConnectionEvent *event);
 GdaConnectionEvent  *gda_connection_add_event_string     (GdaConnection *cnc, const gchar *str, ...);

Modified: trunk/tools/gda-sql.c
==============================================================================
--- trunk/libgda/gda-connection.c	(original)
+++ trunk/libgda/gda-connection.c	Thu Apr 10 05:06:05 2008
@@ -177,7 +177,7 @@
 							       (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 
         g_object_class_install_property (object_class, PROP_AUTH_STRING,
-                                         g_param_spec_string ("auth_string", _("Authentification string to use"),
+                                         g_param_spec_string ("auth_string", _("Authentication string to use"),
                                                               NULL, NULL,
                                                               (G_PARAM_READABLE | G_PARAM_WRITABLE)));
         g_object_class_install_property (object_class, PROP_OPTIONS,
@@ -388,7 +388,7 @@
 /**
  * gda_connection_open_from_dsn
  * @dsn: data source name.
- * @auth_string: authentification string
+ * @auth_string: authentication string
  * @options: options for the connection (see #GdaConnectionOptions).
  * @error: a place to store an error, or %NULL
  *
@@ -396,11 +396,11 @@
  *
  * Establishes a connection to a data source. 
  *
  * The @auth_string must contain the authentification information for the server
  * to accept the connection. It is a string containing semi-colon seperated named value, usually 
  * like "USERNAME=...;PASSWORD=..." where the ... are replaced by actual values. 
  * The actual named parameters required depend on the provider being used, and that list is available
- * as the <parameter>auth_params</parameter> member of the #GdaProviderInfo struncture for each installed
+ * as the <parameter>auth_params</parameter> member of the #GdaProviderInfo structure for each installed
  * provider (use gda_config_get_provider_info() to get it). Also one can use the "gda-sql-4.0 -L" command to 
  * list the possible named parameters.
  *
@@ -461,7 +461,7 @@
  * gda_connection_open_from_string
  * @provider_name: provider ID to connect to, or %NULL
  * @cnc_string: connection string.
- * @auth_string: authentification string
+ * @auth_string: authentication string
  * @options: options for the connection (see #GdaConnectionOptions).
  * @error: a place to store an error, or %NULL
  *
@@ -476,15 +476,15 @@
  * For example the connection string to open an SQLite connection to a database
  * file named "my_data.db" in the current directory would be "DB_DIR=.;DB_NAME=my_data".
  *
  * The @auth_string must contain the authentification information for the server
  * to accept the connection. It is a string containing semi-colon seperated named value, usually 
  * like "USERNAME=...;PASSWORD=..." where the ... are replaced by actual values. 
  * The actual named parameters required depend on the provider being used, and that list is available
- * as the <parameter>auth_params</parameter> member of the #GdaProviderInfo struncture for each installed
+ * as the <parameter>auth_params</parameter> member of the #GdaProviderInfo structure for each installed
  * provider (use gda_config_get_provider_info() to get it). Similarly to the format of the connection
  * string, use the "gda-sql-4.0 -L" command to list the possible named parameters.
  *
- * Additionnally, it is possible to have the connection string
+ * Additionally, it is possible to have the connection string
  * respect the "&lt;provider_name&gt;://&lt;real cnc string&gt;" format, in which case the provider name
  * and the real connection string will be extracted from that string (note that if @provider_name
  * is not %NULL then it will still be used as the provider ID).
@@ -620,7 +620,7 @@
 		if (dsn_info && dsn_info->auth_string)
 			real_auth_string = g_strdup (dsn_info->auth_string);
 		else 
 			/* look for authentification parameters in cnc string */
 			real_auth_string = g_strdup (cnc->priv->cnc_string);
 	}
 
@@ -886,7 +886,7 @@
 }
 
 /**
- * gda_connection_get_authentification
+ * gda_connection_get_authentication
  * @cnc: a #GdaConnection object.
  *
  * Gets the user name used to open this connection.
@@ -894,7 +894,7 @@
  * Returns: the user name.
  */
 const gchar *
-gda_connection_get_authentification (GdaConnection *cnc)
+gda_connection_get_authentication (GdaConnection *cnc)
 {
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
 	g_return_val_if_fail (cnc->priv, NULL);
@@ -396,11 +396,11 @@
  * Establishes a connection to a data source. 
  *
- * The @auth_string must contain the authentification information for the server
+ * The @auth_string must contain the authentication information for the server
  * to accept the connection. It is a string containing semi-colon seperated named value, usually 
  * like "USERNAME=...;PASSWORD=..." where the ... are replaced by actual values. 
@@ -476,15 +476,15 @@
  * file named "my_data.db" in the current directory would be "DB_DIR=.;DB_NAME=my_data".
  *
- * The @auth_string must contain the authentification information for the server
- * to accept the connection. It is a string containing semi-colon seperated named value, usually 
+ * The @auth_string must contain the authentication information for the server
+ * to accept the connection. It is a string containing semi-colon seperated named values, usually 
  * like "USERNAME=...;PASSWORD=..." where the ... are replaced by actual values. 
  * The actual named parameters required depend on the provider being used, and that list is available
@@ -620,7 +620,7 @@
 			real_auth_string = g_strdup (dsn_info->auth_string);
 		else 
-			/* look for authentification parameters in cnc string */
+			/* look for authentication parameters in cnc string */
 			real_auth_string = g_strdup (cnc->priv->cnc_string);
 	}

Modified: trunk/libgda/gda-connection.h
==============================================================================
--- trunk/tools/gda-sql.c	(original)
+++ trunk/tools/gda-sql.c	Thu Apr 10 05:06:05 2008
@@ -1773,9 +1773,9 @@
 			gda_data_model_set_value_at (model, 2, row, value, NULL);
 			gda_value_free (value);
 
 			/* only get USERNAME from the the authentification string */
 			GdaQuarkList* ql;
-			cstr = gda_connection_get_authentification (cs->cnc);
+			cstr = gda_connection_get_authentication (cs->cnc);
 			ql = gda_quark_list_new_from_string (cstr);
 			cstr = gda_quark_list_find (ql, "USERNAME");
 			value = gda_value_new_from_string (cstr ? cstr : "", G_TYPE_STRING);
@@ -1773,9 +1773,9 @@
 			gda_value_free (value);
 
-			/* only get USERNAME from the the authentification string */
+			/* only get USERNAME from the the authentication string */
 			GdaQuarkList* ql;



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]